@@ -1,6 +1,6 @@
 package Map::Tube::Kolkatta::Line::L1;
 
-$Map::Tube::Kolkatta::Line::L1::VERSION   = '0.33';
+$Map::Tube::Kolkatta::Line::L1::VERSION   = '0.34';
 $Map::Tube::Kolkatta::Line::L1::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::Kolkatta::Line::L1 - Kolkatta Metro Map: Line 1.
 
 =head1 VERSION
 
-Version 0.33
+Version 0.34
 
 =cut
 
@@ -72,6 +72,10 @@ Kolkata Metro Map: Line 1.
 
 =back
 
+=head1 MAP DATA
+
+The map data for the line B<L1 - Blue> collected from L<this page|https://en.wikipedia.org/wiki/Blue_Line_(Kolkata_Metro)>.
+
 =head1 MAP
 
 Kolkatta Metro Map: L<Line 1|https://raw.githubusercontent.com/manwar/Map-Tube-Kolkatta/master/maps/L1.png>
@@ -90,50 +94,49 @@ map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
 L<https://github.com/manwar/Map-Tube-Kolkatta>
 
+=head1 SEE ALSO
+
+L<Map::Tube::CLI>
+
 =head1 BUGS
 
-Please  report any bugs/feature requests to C<bug-map-tube-kolkatta at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Kolkatta>.
-I will be notified, and then you'll automatically be notified of progress on your
+Please report any bugs or feature requests through the web interface at L<https://github.com/manwar/Map-Tube-Kolkatta/issues>.
+I will  be notified and then you'll automatically be notified of progress on your
 bug as I make changes.
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Map::Tube::Kolkatta::Line::L1
+    perldoc Map::Tube::Kolkatta
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Map-Tube-Kolkatta>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Map-Tube-Kolkatta>
+L<https://github.com/manwar/Map-Tube-Kolkatta/issues>
 
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Map-Tube-Kolkatta>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/Map-Tube-Kolkatta/>
+L<https://metacpan.org/dist/Map-Tube-Kolkatta/>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2017 Mohammad S Anwar.
+Copyright (C) 2017 - 2025 Mohammad Sajid Anwar.
 
 This program  is  free software; you can redistribute it and / or modify it under
 the  terms  of the the Artistic License (2.0). You may obtain a  copy of the full
